==> haskell-hls-hlint-plugin-2.0.0.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-hlint-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-hlint-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-hlint-plugin-2.0.0.0-GDWxUXDbstaEGnqcqwGyTD
key:                  hls-hlint-plugin-2.0.0.0-GDWxUXDbstaEGnqcqwGyTD
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           atreyu.bbb@gmail.com
author:               The Haskell IDE Team
synopsis:             Hlint integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  cd881c54f410cdf6542e59bbc4c2866a
exposed:              True
exposed-modules:      Ide.Plugin.Hlint
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-hlint-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-hlint-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-hlint-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-hlint-plugin
hs-libraries:         HShls-hlint-plugin-2.0.0.0-GDWxUXDbstaEGnqcqwGyTD
depends:
    Diff-0.4.1-LH1ky1AbixJl32mO74dkD
    aeson-2.1.2.1-5ZyQo9G6Ms46oZtaJgJtcb
    apply-refact-0.11.0.0-RyjEHfgI2U6zmlJjpfjEM base-4.17.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    directory-1.3.7.1 extra-1.7.16-3SBUeFH5sHLJDtonZSgAoM
    filepath-1.4.2.2 ghc-9.4.8 ghc-boot-9.4.8
    ghc-exactprint-1.6.1-JsvwkDVofg3BxdLE532wCX
    ghc-lib-parser-ex-9.4.0.0-J6QLYDzBXMH4S5Mdx3wjfd
    ghcide-2.0.0.0-3b9jhFA8f52IfzEBIRB0hj
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    hlint-3.5-oa9odAapK91j3kJJZbNL4
    hls-plugin-api-2.0.0.0-C6wcsLywVi7Dk1nbG5XhP7
    lens-5.2.3-9GV2xnL92otDGMRfTuRDyv
    lsp-1.6.0.0-FwDzb2GQtLRAHogbqVnKTH
    refact-0.3.0.2-KPJC6T8FqM8EMkV2k8FDeA
    regex-tdfa-1.3.2.2-9m5fW19lHnMJYjjJRSkncP stm-2.5.1.0
    temporary-1.3-5ukCxB0doMQ964otfCXv0z text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:
    /usr/share/doc/haskell-hls-hlint-plugin/html/hls-hlint-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-hlint-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-hlint-plugin-2.0.0.0-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-hlint-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-hlint-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-hlint-plugin-2.0.0.0-EHJw7b1sNZw7PIH3maxffc
key:                  hls-hlint-plugin-2.0.0.0-EHJw7b1sNZw7PIH3maxffc
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           atreyu.bbb@gmail.com
author:               The Haskell IDE Team
synopsis:             Hlint integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  e59b86244b475dd77415bbff5c4fdf43
exposed:              True
exposed-modules:      Ide.Plugin.Hlint
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-hlint-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-hlint-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-hlint-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-hlint-plugin
hs-libraries:         HShls-hlint-plugin-2.0.0.0-EHJw7b1sNZw7PIH3maxffc
depends:
    Diff-0.4.1-LH1ky1AbixJl32mO74dkD
    aeson-2.1.2.1-LpT6Mf0v1IAHC9jBcKu3TC
    apply-refact-0.11.0.0-2NkLn6vMcrbBZKWCk9kH1j base-4.17.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    directory-1.3.7.1 extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK
    filepath-1.4.2.2 ghc-9.4.8 ghc-boot-9.4.8
    ghc-exactprint-1.6.1-B4bBZ972uNZAtSHLc0cZx
    ghc-lib-parser-ex-9.4.0.0-GkELVMqtFZI6ww5YwHbXrH
    ghcide-2.0.0.0-L5q9I4ZYiMTCYArbowTz3S
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    hlint-3.5-DoLR6dP9hflJ5MGtBkV6dt
    hls-plugin-api-2.0.0.0-1mAvF1as5w95rctfx0vZ4l
    lens-5.2.3-1xyXEUn2kF27mSgPIa0sOB
    lsp-1.6.0.0-G6O3LkQ8zqqEpZl3VXzGEp
    refact-0.3.0.2-KPJC6T8FqM8EMkV2k8FDeA
    regex-tdfa-1.3.2.2-9m5fW19lHnMJYjjJRSkncP stm-2.5.1.0
    temporary-1.3-5ukCxB0doMQ964otfCXv0z text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:
    /usr/share/doc/haskell-hls-hlint-plugin/html/hls-hlint-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-hlint-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
